@@ -7,7 +7,8 @@ mice.impute.pls <- function(y, ry, x , type , pls.facs = NULL ,
                                 min.int.cor = 0 , 
 								min.all.cor = 0 , N.largest = 0 ,
 								pls.title = NULL , print.dims= TRUE , 
-								pls.maxcols=5000 ,	... )
+								pls.maxcols=5000 ,	envir_pos = NULL , 
+								extract_data = TRUE , ... )
 {
     #...........................................................................#
     # INPUT                                                                     #
@@ -29,20 +30,26 @@ mice.impute.pls <- function(y, ry, x , type , pls.facs = NULL ,
     #...........................................................................#
  
 	time1 <- base::Sys.time()	
-	
+
 	#--- extract arguments
-	pos <- base::parent.frame(n=1)
+	if ( is.null(envir_pos) ){
+		pos <- base::parent.frame(n=1)
+	} else {
+		pos <- envir_pos
+	}
 	res <- mice_imputation_get_states( pos = pos )				
 	vname <- res$vname
 	imp.temp <- res$newstate			
 		#...  newstate <- list(it = k,  im = i,  co = j, dep = vname,  meth = theMethod,
-		#...	               log = oldstate$log)		
-	res <- mice_imputation_prepare_2l_functions( vname = vname , envir = pos )		
-	y <- res$y
-	x <- res$x
-	ry <- res$ry
-	type <- res$type
-		
+		#...	               log = oldstate$log)	
+	
+	if (extract_data){	
+		res <- mice_imputation_prepare_2l_functions( vname = vname , envir = pos )		
+		y <- res$y
+		x <- res$x
+		ry <- res$ry
+		type <- res$type
+	}	
 	n <- NULL
 	# normalize imputation weights
     imputationWeights <- normalize_vector( x = imputationWeights)
@@ -56,7 +63,7 @@ mice.impute.pls <- function(y, ry, x , type , pls.facs = NULL ,
 				vname , base::list() )				
     # define minimal correlation for interactions
     min.int.cor <- mice_imputation_extract_list_arguments( min.int.cor , vname , 0 ) 
-
+	
     #*** print progress | print section 1
 	res <- mice_imputation_pls_print_progress1( pls.print.progress , vname ,
 					print.dims , y , ry , x , type )
@@ -72,13 +79,13 @@ mice.impute.pls <- function(y, ry, x , type , pls.facs = NULL ,
 	# standardize matrix of covariates
 	x <- mice_imputation_pls_scale_x( x=x , imputationWeights=imputationWeights , 
 			use_weights=use_weights )
-
+			
 	# include cluster effects (adjusted group mean)	
 	res <- mice_imputation_include_cluster_effect( x=x , y=y , ry=ry , type=type )
 	type <- res$type
 	x0 <- x10 <- x <- res$x
 	N <- base::ncol(x)
-
+	
     #*** print progress | print section 2   
 	res <- mice_imputation_pls_print_progress2(pls.print.progress , imp.temp,
 				pls.title, y , x)
@@ -86,33 +93,34 @@ mice.impute.pls <- function(y, ry, x , type , pls.facs = NULL ,
     # extract interactions and quadratic terms
     pls.interactions <- base::names(type)[ type == 4 ]
     pls.quadratics <- base::names(type)[ type == 5 ]   
-
+	
 	#-- include interactions
 	res <- mice_imputation_pls_include_interactions(pls.interactions , 
 				pls.print.progress, x , y , ry , type , min.int.cor , pls.maxcols )
 	x <- res$x
 	xs <- res$xs
-
+	
 	#-- include quadratic terms
 	res <- mice_imputation_pls_include_quadratics( pls.quadratics , 
 				pls.interactions , x0 , x , pls.print.progress , xs )	
 	x <- res$x
-
+	
 	#-- include only terms with largest correlations
 	res <- mice_imputation_pls_largest_correlations( y , x , ry , type ,
 				use.ymat , pls.print.progress , x10 , N.largest , min.all.cor )
 	x <- res$x
-
+		
 	#-- perform PCA if requested
 	x <- mice_imputation_pls_pca_reduction(x , pcamaxcols ,	pls.print.progress)
 	x10 <- x	# copy dataset of predictors
 
+	
 	#--- perform PLS regression	
 	res <- mice_imputation_pls_estimate_pls_regression( pls.facs , x , y, ry ,
 				use.ymat , imputationWeights , use_weights , pls.print.progress )
 	x <- res$x
 	x11a <- res$x11a
-		
+	
 	#--- apply imputation method
 	x1 <- mice_imputation_pls_do_impute( x , y , ry , imputationWeights , 
 				use_weights , pls.impMethod ,
